@@ -196,6 +196,7 @@ from polars.functions import (
     time,
     time_range,
     time_ranges,
+    union,
     var,
     when,
     zeros,
@@ -369,6 +370,7 @@ __all__ = [
     "arg_where",
     "business_day_count",
     "concat",
+    "union",
     "dtype_of",
     "struct_with_fields",
     "date_range",
