@@ -4,6 +4,7 @@ from collections.abc import Sequence
 from typing import TYPE_CHECKING, Any, Callable
 
 from polars import functions as F
+from polars._utils.unstable import unstable
 from polars._utils.wrap import wrap_s
 from polars.series.utils import expr_dispatch
 
@@ -570,6 +571,35 @@ class ListNameSpace:
         ]
         """
 
+    @unstable()
+    def item(self) -> Series:
+        """
+        Get the single value of the sublists.
+
+        This errors if the sublist length is not exactly one.
+
+        See Also
+        --------
+        :meth:`Series.list.get` : Get the value by index in the sublists.
+
+        Examples
+        --------
+        >>> s = pl.Series("a", [[1], [4], [6]])
+        >>> s.list.item()
+        shape: (3,)
+        Series: 'a' [i64]
+        [
+            1
+            4
+            6
+        ]
+        >>> df = pl.Series("a", [[3, 2, 1], [1], [2]])
+        >>> df.list.item()
+        Traceback (most recent call last):
+        ...
+        polars.exceptions.ComputeError: aggregation 'item' expected a single value, got 3 values
+        """  # noqa: W505
+
     def contains(self, item: IntoExpr, *, nulls_equal: bool = True) -> Series:
         """
         Check if sublists contain the given item.
@@ -962,6 +992,37 @@ class ListNameSpace:
         ]
         """
 
+    def agg(self, expr: Expr) -> Series:
+        """
+
+        Run any polars aggregation expression against the list' elements.
+
+        Parameters
+        ----------
+        expr
+            Expression to run. Note that you can select an element with `pl.element()`.
+
+        Examples
+        --------
+        >>> s = pl.Series("a", [[1, None], [42, 13], [None, None]])
+        >>> s.list.agg(pl.element().null_count())
+        shape: (3,)
+        Series: 'a' [u32]
+        [
+            1
+            0
+            2
+        ]
+        >>> s.list.agg(pl.element().drop_nulls())
+        shape: (3,)
+        Series: 'a' [list[i64]]
+        [
+            [1]
+            [42, 13]
+            []
+        ]
+        """
+
     def filter(self, predicate: Expr) -> Series:
         """
         Filter elements in each list by a boolean expression, returning a new Series of lists.
